# Tangent Works Python Client

Tangent Information Modeler is Tangent Works' automatic model building engine.
It is designed specifically for time-series forecasting and anomaly detection.

The Tangent Works Python client introduces an easy and fast way to use Tangent Works in any Python project.

## Usage

### Installation

To install the package run: `pip install tangent-client`

## About Tangent Works

Tangent Works delivers forecasting and anomaly detection capabilities for time series data in a fast,
accurate and explainable way. This enables users to drive business value from predictive analytics,
empowers them to take informed decisions and helps them improve processes.

TIM has already been recognized as a winner in multiple competitions, including GEFCom 2017 and the 2017 ANDRITZ Hackathon.
